//
//  This file is part of Siena, a wide-area event notification system.
//  See http://www.inf.unisi.ch/carzaniga/siena/
//
//  Author: Antonio Carzaniga (firstname.lastname@unisi.ch)
//  See the file AUTHORS for full details. 
//
//  Copyright (C) 1998-2002 University of Colorado
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
//  USA, or send email to Antonio Carzaniga (firstname.lastname@unisi.ch).
//
package sienatest;

import siena.Siena;
import siena.Notification;
import siena.Filter;
import siena.Notifiable;
import siena.AttributeValue;
import siena.HierarchicalDispatcher;
import siena.SienaException;
import java.net.InetAddress;

class Subscriber implements Notifiable {
    int counter;

    public Subscriber(int c) throws SienaException {
	counter = c;
	Filter f = new Filter();
	f.addConstraint("x", counter);
	TestLocalPubSub.siena.subscribe(f, this);
    } 

    public void notify(Notification e[]) throws SienaException { }

    public void notify(Notification e) throws SienaException {
	System.out.println(Integer.toString(counter)+ ":" + e.toString());
	
	AttributeValue a = e.getAttribute("x");
	if (a == null) {
	    System.err.println("Error: attribute `x' is missing.");
	} else if (a.getType() != AttributeValue.INT 
		   || a.intValue() != counter) {
	    System.err.println("Error: unexpected value for attribute `x'.");
	} else { 
	    if (counter > 0) {
		Filter fu = new Filter();
		fu.addConstraint("x", counter);
		TestLocalPubSub.siena.unsubscribe(fu, this);
		counter--;
		
		Filter f = new Filter();
		f.addConstraint("x", counter);
		TestLocalPubSub.siena.subscribe(f,this);
	    } else {
		TestLocalPubSub.siena.unsubscribe(this);
	    }
	}
    }
}

public class TestLocalPubSub {

    static public HierarchicalDispatcher siena;

    static public void main(String argv[]) {
	try {
	    if (argv.length == 0) {
		System.out.println("usage: TestLocalPubSub <n1> [...]");
		System.exit(-1);
	    }
	    siena = new HierarchicalDispatcher();
	    Notifiable [] subscribers = new Notifiable[argv.length];
	    
	    for(int i = 0; i < argv.length; ++i) 
		subscribers[i] = new Subscriber(Integer.decode(argv[i]).intValue());
	    
	    Notification e = new Notification();
	    e.putAttribute("extra", "whatever"); 
	    for (int i = 0; i < 10; i++)
		for (int j = 0; j < 10; j++) {
		    Thread.sleep(100);
		    e.putAttribute("x", j);
		    siena.publish(e);
		}
	    for(int i = 0; i < argv.length; ++i) 
		siena.unsubscribe(subscribers[i]);
	    siena.shutdown();
	}
	catch (Exception e) {
	    e.printStackTrace();
	}
    }
}
