//
//  This file is part of Siena, a wide-area event notification system.
//  See http://www.inf.unisi.ch/carzaniga/siena/
//
//  Author: Antonio Carzaniga (firstname.lastname@unisi.ch)
//  See the file AUTHORS for full details. 
//
//  Copyright (C) 1998-2002 University of Colorado
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
//  USA, or send email to Antonio Carzaniga (firstname.lastname@unisi.ch).
//
package sienatest;

import siena.*;
import siena.comm.*;
import java.io.BufferedReader;
import java.io.InputStreamReader;

public class TestPacketSender {
    static PacketSenderFactory sender_factory = new GenericSenderFactory();

    public static void main(String argv[]) {
	try {
	    PacketSender sender = null;
	    String inl;
	    int sleepytime = -1;
	    int i = 0;
	    boolean quiet = false;

	    if (i < argv.length && argv[0].equals("-quiet")) {
		quiet = true;
		++i;
	    }
	    switch (argv.length - i) {
	    case 2: sleepytime = Integer.parseInt(argv[i + 1]);
	    case 1: 
		sender = sender_factory.createPacketSender(argv[i]);
		break;
	    default:
		System.out.println("usage: TestPacketSender <address> [<millisecs>]");
		System.exit(1);
	    }

	    BufferedReader in
		= new BufferedReader(new InputStreamReader(System.in));

	    if (quiet) {
		while ((inl = in.readLine()) != null) {
		    sender.send(inl.getBytes());
		    if (sleepytime > 0) 
			Thread.sleep(sleepytime);
		}
	    } else {
		while ((inl = in.readLine()) != null) {
		    System.out.print("#");
		    sender.send(inl.getBytes());
		    if (sleepytime > 0) 
			Thread.sleep(sleepytime);
		}
		System.out.println(".");
	    }
	}
	catch (Exception e) {
	    e.printStackTrace();
	    System.exit(1);
	}
    }
}
